@@ -27,14 +27,19 @@ class SubscriptionAdmin(admin.ModelAdmin):
     readonly_fields = (
             'created_at', 'updated_at', 'user',
             'plan', 'customer_id', 'subscription_id', 'quiz')
-    list_display = ('user', 'created_at', 'updated_at',
+    list_display = ('user_email', 'created_at', 'updated_at',
                     'customer_id', 'subscription_id', 'is_active')
+    search_fields = ('user__email', 'customer_id', 'subscription_id')
     list_filter = ('is_active', 'created_at')
 
     def stripe_plan(self, obj=None):
         if obj:
             return obj.plan.title
 
+    def user_email(self, obj=None):
+        if obj:
+            return obj.user.email or 'not specified'
+
     stripe_plan.short_description = 'Plan'
 
     def get_fieldsets(self, request, obj=None):
