@@ -104,8 +104,10 @@ class Subscription(models.Model):
                     customer=obj.customer_id,
                     items=[
                         {"price": plan.price_id}
-                    ],
-                    trial_end=utils.get_trial_end(plan.trial_days))
+                    ])
+
+            if plan.trial_days:
+                kwargs['trial_end'] = utils.get_trial_end(plan.trial_days)
 
             if token.startswith('tok_'):
                 token = stripe.Token.retrieve(token)
