@@ -1,3 +1,6 @@
+import json
+import urllib.request
+
 from django.apps import apps
 from django.core import signing
 from django.http import JsonResponse, Http404
@@ -101,7 +104,17 @@ def check_subscription(request):
         return JsonResponse({"is_active": obj.is_active})
 
     except Subscription.DoesNotExist:
-        raise Http404
+        # TODO: remove this shit code
+        url = 'https://tetris-puzzle.com/api/subscription/check/'
+        data = 'subscription_id=%s' % form.cleaned_data['subscription_id']
+
+        with urllib.request.urlopen(url, data=data.encode()) as resp:
+            if resp.status == 404:
+                raise Http404
+
+            data = json.loads(resp.read().decode('utf-8'))
+
+            return JsonResponse(data, status=resp.status)
 
     return JsonResponse({"status": "error", "error": "Something went wrong"}, status=400)
 
@@ -131,7 +144,17 @@ def cancel_subscription(request):
             return JsonResponse({"status": "ok"})
 
     except Subscription.DoesNotExist:
-        raise Http404
+        # TODO: remove this shit code
+        url = 'https://tetris-puzzle.com/api/subscription/cancel/'
+        data = 'subscription_id=%s' % form.cleaned_data['subscription_id']
+
+        with urllib.request.urlopen(url, data=data.encode()) as resp:
+            if resp.status == 404:
+                raise Http404
+
+            data = json.loads(resp.read().decode('utf-8'))
+
+            return JsonResponse(data, status=resp.status)
 
     return JsonResponse({"status": "error", "error": "Something went wrong"}, status=400)
 
